-- PlayerSetup Addon for WoW 5.4.8 - Reorganized Heirloom Kits
-- Send prebuilt kits to players via GM commands

-- Trinket definitions - Using ONLY Level 85+ versions
local swiftHandOfJustice = "93896"  -- Forceful Hand of Justice (Level 85+ melee trinket)
local discerningEyeOfBeast = "93897"  -- Piercing Eye of the Beast (Level 85+ caster trinket)
local forcefulHandOfJustice = "93896"  -- Upgraded melee trinket
local piercingEyeOfBeast = "93897"  -- Upgraded caster trinket

-- Weapon collections by role - ALL LEVEL 85+ ONLY
local meleeWeapons = {
    -- One-handed weapons (Level 85+)
    "93847",  -- Crushing Mass of McGowan (Agility)
    "93845",  -- Gore-Steeped Skullforge Reaver (Strength)
    "93856",  -- Noble Dal'Rend's Sacred Charge (Agility)
    "93848",  -- Battle-Hardened Thrash Blade (proc weapon)
    "93858",  -- Brawler's Bladed Claws (Agility)
    "93857",  -- Vengeful Heartseeker (Agility)
    "93852",  -- Deadly Scarlet Kris (Agility)
    -- Ranged weapons (Level 85+)
    "93841",  -- Smoothbore Dwarven Hand Cannon (Agility)
    "93855",  -- War-Torn Ancient Bone Bow (Agility)
    -- Shields (Level 85+)
    "93902",  -- Flamescarred Draconian Deflector (Strength)
    -- Two-handed weapons (Level 85+)
    "93851",  -- Battle-Forged Truesilver Champion (Strength)
    "93843",  -- Hardened Arcanite Reaper (Strength)
    "93846",  -- Re-Engineered Lava Dredger (Agility)
    "93844"   -- Refinished Warden Staff (Agility)
}

local casterWeapons = {
    -- One-handed weapons (Level 85+)
    "93853",  -- Pious Aurastone Hammer (Intellect)
    "93850",  -- The Sanctified Hammer of Grace (spell power)
    -- Offhands (Level 85+)
    "93904",  -- Musty Tome of the Lost (Intellect)
    "93903",  -- Weathered Observer's Shield (Intellect)
    -- Two-handed weapons (Level 85+)
    "93854",  -- Scholarly Headmaster's Charge (Intellect)
    "93849"   -- Elder Staff of Jordan (spell power)
}

-- Timer frame for delayed weapon sending
local timerFrame = CreateFrame("Frame")
local pendingWeaponSends = {}

-- Kit definitions organized by armor type and role
local kits = {
    -- Plate Kits
    ["Plate Melee"] = {
        type = "items",
        subject = "Plate Melee Heirloom Kit",
        body = "Your plate melee heirloom armor kit has arrived!",
        items = "93892 93893 62023 61931 62039 50255 " .. swiftHandOfJustice .. " " .. swiftHandOfJustice,
        category = "Plate",
        role = "melee"
    },
    ["Plate Tank"] = {
        type = "items",
        subject = "Plate Tank Heirloom Kit",
        body = "Your plate tank heirloom armor kit has arrived!",
        items = "93892 93893 62023 61931 62039 50255 " .. swiftHandOfJustice .. " " .. swiftHandOfJustice,
        category = "Plate",
        role = "melee"
    },
    ["Plate Caster"] = {
        type = "items",
        subject = "Plate Caster Heirloom Kit",
        body = "Your plate caster heirloom armor kit has arrived!",
        items = "93891 93894 62023 61931 62039 50255 " .. discerningEyeOfBeast .. " " .. discerningEyeOfBeast,
        category = "Plate",
        role = "caster"
    },
    
    -- Leather Kits  
    ["Leather Melee"] = {
        type = "items",
        subject = "Leather Melee Heirloom Kit",
        body = "Your leather melee heirloom armor kit has arrived!",
        items = "93863 93862 62026 61937 62039 50255 " .. swiftHandOfJustice .. " " .. swiftHandOfJustice,
        category = "Leather",
        role = "melee"
    },
    ["Leather Caster"] = {
        type = "items",
        subject = "Leather Caster Heirloom Kit", 
        body = "Your leather caster heirloom armor kit has arrived!",
        items = "93865 93864 62027 61942 93866 62039 50255 " .. discerningEyeOfBeast .. " " .. discerningEyeOfBeast,
        category = "Leather",
        role = "caster"
    },
    
    -- Mail Kits
    ["Mail Melee"] = {
        type = "items",
        subject = "Mail Melee Heirloom Kit",
        body = "Your mail melee heirloom armor kit has arrived!",
        items = "93888 93887 62024 61935 93886 62039 50255 " .. swiftHandOfJustice .. " " .. swiftHandOfJustice,
        category = "Mail", 
        role = "melee"
    },
    ["Mail Caster"] = {
        type = "items",
        subject = "Mail Caster Heirloom Kit",
        body = "Your mail caster heirloom armor kit has arrived!",
        items = "93885 93876 62025 61936 93889 62039 50255 " .. discerningEyeOfBeast .. " " .. discerningEyeOfBeast,
        category = "Mail",
        role = "caster"
    },
    
    -- Cloth Kits
    ["Cloth Caster"] = {
        type = "items", 
        subject = "Cloth Caster Heirloom Kit",
        body = "Your cloth caster heirloom armor kit has arrived!",
        items = "93860 93859 62029 61958 93861 62039 50255 " .. discerningEyeOfBeast .. " " .. discerningEyeOfBeast,
        category = "Cloth",
        role = "caster"
    }
}

-- Custom utility items with input fields
local utilityItems = {
    ["Bags"] = {
        type = "items",
        subject = "Bag Delivery",
        body = "Your bags have arrived!",
        itemId = "1100",
        defaultAmount = 4
    },
    ["Gold"] = {
        type = "money",
        subject = "Gold Delivery", 
        body = "Your gold has arrived!",
        defaultAmount = 1000
    }
}

-- Store input fields for utility items
local utilityInputs = {}

-- Function to send weapons for role
local function SendWeapons(playerName, role)
    if not playerName or playerName == "" then
        DEFAULT_CHAT_FRAME:AddMessage("Error: Please enter a player name!", 1, 0, 0)
        return
    end
    
    local weapons = role == "melee" and meleeWeapons or casterWeapons
    local weaponsString = table.concat(weapons, " ")
    local subject = role == "melee" and "Melee Heirloom Weapons" or "Caster Heirloom Weapons"
    local body = "Choose your preferred weapons from this collection!"
    
    local command = string.format('.send items %s "%s" "%s" %s', 
        playerName, subject, body, weaponsString)
    
    SendChatMessage(command)
    DEFAULT_CHAT_FRAME:AddMessage(string.format("Sent %s weapons to %s", role, playerName), 0, 1, 0)
    DEFAULT_CHAT_FRAME:AddMessage("Weapons Command: " .. command, 0.7, 0.7, 0.7)
end

-- Timer frame OnUpdate for delayed weapon sending
timerFrame:SetScript("OnUpdate", function(self, elapsed)
    for i = #pendingWeaponSends, 1, -1 do
        local pending = pendingWeaponSends[i]
        pending.timeLeft = pending.timeLeft - elapsed
        
        if pending.timeLeft <= 0 then
            SendWeapons(pending.playerName, pending.role)
            table.remove(pendingWeaponSends, i)
        end
    end
    
    -- Hide frame when no pending sends
    if #pendingWeaponSends == 0 then
        self:Hide()
    end
end)

-- Function to schedule weapon sending
local function ScheduleWeaponSend(playerName, role, delay)
    table.insert(pendingWeaponSends, {
        playerName = playerName,
        role = role,
        timeLeft = delay or 1.0
    })
    timerFrame:Show()
end

-- Function to send kit to player with automatic weapon follow-up
local function SendKit(playerName, kitName)
    if not playerName or playerName == "" then
        DEFAULT_CHAT_FRAME:AddMessage("Error: Please enter a player name!", 1, 0, 0)
        return
    end
    
    if not kits[kitName] then
        DEFAULT_CHAT_FRAME:AddMessage("Error: Kit not found!", 1, 0, 0)
        return
    end
    
    local kit = kits[kitName]
    local command = ""
    
    if kit.type == "items" then
        command = string.format('.send items %s "%s" "%s" %s', 
            playerName, kit.subject, kit.body, kit.items)
    elseif kit.type == "money" then
        command = string.format('.send money %s "%s" "%s" %s',
            playerName, kit.subject, kit.body, kit.amount)
    end
    
    SendChatMessage(command)
    DEFAULT_CHAT_FRAME:AddMessage(string.format("Sent %s armor kit to %s", kitName, playerName), 0, 1, 0)
    DEFAULT_CHAT_FRAME:AddMessage("Armor Command: " .. command, 0.7, 0.7, 0.7)
    
    -- Schedule weapons for the role
    if kit.role then
        ScheduleWeaponSend(playerName, kit.role, 1.0)
        DEFAULT_CHAT_FRAME:AddMessage(string.format("Weapons will be sent in 1 second..."), 0.8, 0.8, 1)
    end
end

-- Function to send custom utility item
local function SendUtilityItem(playerName, itemName, amount)
    if not playerName or playerName == "" then
        DEFAULT_CHAT_FRAME:AddMessage("Error: Please enter a player name!", 1, 0, 0)
        return
    end
    
    local item = utilityItems[itemName]
    if not item then
        DEFAULT_CHAT_FRAME:AddMessage("Error: Utility item not found!", 1, 0, 0)
        return
    end
    
    local command = ""
    
    if item.type == "items" then
        -- Create items string by repeating the item ID
        local itemsString = ""
        for i = 1, amount do
            if i > 1 then
                itemsString = itemsString .. " "
            end
            itemsString = itemsString .. item.itemId
        end
        command = string.format('.send items %s "%s" "%s" %s', 
            playerName, item.subject, item.body, itemsString)
    elseif item.type == "money" then
        -- Convert gold to copper (multiply by 10000)
        local copperAmount = amount * 10000
        command = string.format('.send money %s "%s" "%s" %s',
            playerName, item.subject, item.body, copperAmount)
    end
    
    SendChatMessage(command)
    DEFAULT_CHAT_FRAME:AddMessage(string.format("Sent %d %s to %s", amount, itemName, playerName), 0, 1, 0)
    DEFAULT_CHAT_FRAME:AddMessage("Command: " .. command, 0.7, 0.7, 0.7)
end

-- Create main frame - wider and shorter
local mainFrame = CreateFrame("Frame", "PlayerSetupMainFrame", UIParent)
mainFrame:SetSize(500, 350)
mainFrame:SetPoint("CENTER", UIParent, "CENTER", 0, 0)
mainFrame:SetBackdrop({
    bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background",
    edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Border",
    tile = true, tileSize = 32, edgeSize = 32,
    insets = { left = 11, right = 12, top = 12, bottom = 11 }
})
mainFrame:SetBackdropColor(0, 0, 0, 0.8)
mainFrame:SetMovable(true)
mainFrame:EnableMouse(true)
mainFrame:RegisterForDrag("LeftButton")
mainFrame:SetScript("OnDragStart", mainFrame.StartMoving)
mainFrame:SetScript("OnDragStop", mainFrame.StopMovingOrSizing)

-- Title text
local titleText = mainFrame:CreateFontString(nil, "OVERLAY", "GameFontNormalLarge")
titleText:SetPoint("TOP", mainFrame, "TOP", 0, -15)
titleText:SetText("Heirloom Kit Setup")
titleText:SetTextColor(1, 0.82, 0)

-- Player name section
local playerLabel = mainFrame:CreateFontString(nil, "OVERLAY", "GameFontNormal")
playerLabel:SetPoint("TOPLEFT", mainFrame, "TOPLEFT", 20, -50)
playerLabel:SetText("Player Name:")

local playerInput = CreateFrame("EditBox", "PlayerSetupNameInput", mainFrame, "InputBoxTemplate")
playerInput:SetSize(150, 20)
playerInput:SetPoint("LEFT", playerLabel, "RIGHT", 10, 0)
playerInput:SetAutoFocus(false)

-- Current selection display
local selectionLabel = mainFrame:CreateFontString(nil, "OVERLAY", "GameFontNormal")
selectionLabel:SetPoint("LEFT", playerInput, "RIGHT", 20, 0)
selectionLabel:SetText("Selected:")

local currentKit = "Plate Melee"
local kitDisplay = mainFrame:CreateFontString(nil, "OVERLAY", "GameFontHighlight")
kitDisplay:SetPoint("LEFT", selectionLabel, "RIGHT", 5, 0)
kitDisplay:SetText(currentKit)
kitDisplay:SetTextColor(0.8, 1, 0.8)

-- Category tabs
local categories = {"Plate", "Leather", "Mail", "Cloth", "Utility"}
local selectedCategory = "Plate"
local categoryButtons = {}
local kitButtons = {}

-- Create category buttons with clean styling
local tabStartX = 20
for i, category in ipairs(categories) do
    local tabButton = CreateFrame("Button", nil, mainFrame, "UIPanelButtonTemplate")
    tabButton:SetSize(85, 25)
    tabButton:SetPoint("TOPLEFT", mainFrame, "TOPLEFT", tabStartX + (i-1) * 90, -85)
    tabButton:SetText(category)
    
    tabButton:SetScript("OnClick", function()
        selectedCategory = category
        -- Update all buttons appearance
        for cat, btn in pairs(categoryButtons) do
            if cat == category then
                -- Selected button - disable it and change text color
                btn:Disable()
                btn:GetFontString():SetTextColor(1, 0.82, 0) -- Gold text
            else
                -- Unselected buttons - enable and white text
                btn:Enable()
                btn:GetFontString():SetTextColor(1, 1, 1) -- White text
            end
        end
        -- Show kits for this category
        ShowKitsForCategory(category)
    end)
    
    categoryButtons[category] = tabButton
    
    -- Set initial appearance
    if category == selectedCategory then
        tabButton:Disable()
        tabButton:GetFontString():SetTextColor(1, 0.82, 0)
    else
        tabButton:Enable()
        tabButton:GetFontString():SetTextColor(1, 1, 1)
    end
end

-- Function to show kits for selected category
function ShowKitsForCategory(category)
    -- Hide all kit buttons first
    for _, button in pairs(kitButtons) do
        button:Hide()
    end
    
    -- Hide all utility inputs
    for _, inputData in pairs(utilityInputs) do
        if inputData and inputData.container then
            inputData.container:Hide()
        end
    end
    
    if category == "Utility" then
        -- Show utility items with custom input fields
        local startY = -130
        local itemHeight = 35
        local yOffset = 0
        
        -- Create containers in a specific order for consistency
        local orderedItems = {"Gold", "Bags"}
        
        for _, itemName in ipairs(orderedItems) do
            local item = utilityItems[itemName]
            if item then
                local inputData = utilityInputs[itemName]
                if not inputData or not inputData.container then
                    -- Create container for this utility item
                    local container = CreateFrame("Frame", nil, mainFrame)
                    container:SetSize(460, itemHeight)
                    
                    -- Item label
                    local label = container:CreateFontString(nil, "OVERLAY", "GameFontNormal")
                    label:SetPoint("LEFT", container, "LEFT", 0, 0)
                    label:SetText(itemName .. ":")
                    label:SetTextColor(1, 1, 1)
                    
                    -- Amount input
                    local input = CreateFrame("EditBox", nil, container, "InputBoxTemplate")
                    input:SetSize(80, 20)
                    input:SetPoint("LEFT", label, "RIGHT", 10, 0)
                    input:SetAutoFocus(false)
                    input:SetNumeric(true)
                    
                    -- Set text after creating the input box completely
                    input:SetText(tostring(item.defaultAmount))
                    input:HighlightText(0, 0) -- Clear any selection
                    input:SetCursorPosition(0)
                    
                    -- Send button
                    local sendBtn = CreateFrame("Button", nil, container, "UIPanelButtonTemplate")
                    sendBtn:SetSize(80, 25)
                    sendBtn:SetPoint("LEFT", input, "RIGHT", 10, 0)
                    sendBtn:SetText("Send " .. itemName)
                    sendBtn:SetScript("OnClick", function()
                        local playerName = playerInput:GetText()
                        local amount = tonumber(input:GetText()) or item.defaultAmount
                        if amount <= 0 then
                            DEFAULT_CHAT_FRAME:AddMessage("Error: Amount must be greater than 0!", 1, 0, 0)
                            return
                        end
                        SendUtilityItem(playerName, itemName, amount)
                    end)
                    
                    -- Info text
                    local infoText = container:CreateFontString(nil, "OVERLAY", "GameFontNormalSmall")
                    infoText:SetPoint("LEFT", sendBtn, "RIGHT", 15, 0)
                    if item.type == "money" then
                        infoText:SetText("(1 = 1 gold)")
                    else
                        infoText:SetText("(Number of " .. itemName:lower() .. ")")
                    end
                    infoText:SetTextColor(0.7, 0.7, 0.7)
                    
                    -- Store references
                    utilityInputs[itemName] = {
                        container = container,
                        input = input,
                        button = sendBtn,
                        label = label,
                        info = infoText
                    }
                    
                    inputData = utilityInputs[itemName]
                end
                
                -- Always clear previous positioning and set new position
                inputData.container:ClearAllPoints()
                inputData.container:SetPoint("TOPLEFT", mainFrame, "TOPLEFT", 20, startY - yOffset)
                inputData.container:Show()
                yOffset = yOffset + itemHeight + 10
            end
        end
    else
        -- Show regular kit buttons for other categories
        local buttonCount = 0
        local startY = -130
        local buttonsPerRow = 2
        local buttonWidth = 220
        local buttonHeight = 25
        local spacing = 10
        
        for kitName, kit in pairs(kits) do
            if kit.category == category then
                local button = kitButtons[kitName]
                if not button then
                    -- Create button if it doesn't exist
                    button = CreateFrame("Button", nil, mainFrame, "UIPanelButtonTemplate")
                    button:SetSize(buttonWidth, buttonHeight)
                    button:SetText(kitName)
                    button:SetScript("OnClick", function()
                        currentKit = kitName
                        kitDisplay:SetText(currentKit)
                        
                        -- Show kit details
                        if kit.type == "items" then
                            DEFAULT_CHAT_FRAME:AddMessage("Selected: " .. kitName .. " (Items: " .. kit.items .. ")", 0.8, 0.8, 1)
                        else
                            DEFAULT_CHAT_FRAME:AddMessage("Selected: " .. kitName .. " (Amount: " .. kit.amount .. ")", 0.8, 0.8, 1)
                        end
                        
                        -- Highlight selected button
                        for _, btn in pairs(kitButtons) do
                            if btn:IsShown() then
                                btn:SetAlpha(0.8)
                            end
                        end
                        button:SetAlpha(1.0)
                    end)
                    kitButtons[kitName] = button
                end
                
                -- Position button
                local row = math.floor(buttonCount / buttonsPerRow)
                local col = buttonCount % buttonsPerRow
                local x = 20 + col * (buttonWidth + spacing)
                local y = startY - row * (buttonHeight + spacing)
                
                button:ClearAllPoints()
                button:SetPoint("TOPLEFT", mainFrame, "TOPLEFT", x, y)
                button:Show()
                button:SetAlpha(0.8)
                
                buttonCount = buttonCount + 1
            end
        end
        
        -- Update current kit if it's not in the new category
        local kitInCategory = false
        for kitName, kit in pairs(kits) do
            if kit.category == category and kitName == currentKit then
                kitInCategory = true
                break
            end
        end
        
        if not kitInCategory then
            -- Set to first kit in this category
            for kitName, kit in pairs(kits) do
                if kit.category == category then
                    currentKit = kitName
                    kitDisplay:SetText(currentKit)
                    break
                end
            end
        end
    end
end

-- Action buttons (only show for non-utility categories)
local sendButton = CreateFrame("Button", "PlayerSetupSendButton", mainFrame, "UIPanelButtonTemplate")
sendButton:SetSize(120, 30)
sendButton:SetPoint("BOTTOMLEFT", mainFrame, "BOTTOMLEFT", 20, 15)
sendButton:SetText("Send Kit + Weapons")
sendButton:SetScript("OnClick", function()
    if selectedCategory == "Utility" then
        DEFAULT_CHAT_FRAME:AddMessage("Use the individual send buttons for utility items!", 1, 0.5, 0)
        return
    end
    local playerName = playerInput:GetText()
    SendKit(playerName, currentKit)
end)

local clearButton = CreateFrame("Button", "PlayerSetupClearButton", mainFrame, "UIPanelButtonTemplate")
clearButton:SetSize(80, 30)
clearButton:SetPoint("LEFT", sendButton, "RIGHT", 10, 0)
clearButton:SetText("Clear")
clearButton:SetScript("OnClick", function()
    playerInput:SetText("")
    playerInput:SetFocus()
end)

-- Info text about the two-mail system
local infoText = mainFrame:CreateFontString(nil, "OVERLAY", "GameFontNormalSmall")
infoText:SetPoint("BOTTOM", mainFrame, "BOTTOM", 0, 50)
infoText:SetText("Each kit sends TWO mails: armor first, then all weapons for the role")
infoText:SetTextColor(0.8, 0.8, 1)

-- Quick send buttons for common actions (moved and adjusted)
local quickBagsButton = CreateFrame("Button", nil, mainFrame, "UIPanelButtonTemplate")
quickBagsButton:SetSize(80, 25)
quickBagsButton:SetPoint("BOTTOMRIGHT", mainFrame, "BOTTOMRIGHT", -100, 15)
quickBagsButton:SetText("Quick Bags")
quickBagsButton:SetScript("OnClick", function()
    local playerName = playerInput:GetText()
    if playerName and playerName ~= "" then
        SendUtilityItem(playerName, "Bags", 4)
    else
        DEFAULT_CHAT_FRAME:AddMessage("Enter player name first!", 1, 0.5, 0)
    end
end)

local quickMoneyButton = CreateFrame("Button", nil, mainFrame, "UIPanelButtonTemplate")
quickMoneyButton:SetSize(80, 25)
quickMoneyButton:SetPoint("RIGHT", quickBagsButton, "LEFT", -5, 0)
quickMoneyButton:SetText("Quick Gold")
quickMoneyButton:SetScript("OnClick", function()
    local playerName = playerInput:GetText()
    if playerName and playerName ~= "" then
        SendUtilityItem(playerName, "Gold", 1000)
    else
        DEFAULT_CHAT_FRAME:AddMessage("Enter player name first!", 1, 0.5, 0)
    end
end)

-- Close button
local closeButton = CreateFrame("Button", "PlayerSetupCloseButton", mainFrame, "UIPanelCloseButton")
closeButton:SetPoint("TOPRIGHT", mainFrame, "TOPRIGHT", -5, -5)
closeButton:SetScript("OnClick", function()
    mainFrame:Hide()
end)

-- Initialize the display
ShowKitsForCategory(selectedCategory)

-- Register slash commands
SLASH_PLAYERSETUP1 = "/playersetup"
SLASH_PLAYERSETUP2 = "/psetup"

SlashCmdList["PLAYERSETUP"] = function(msg)
    if msg == "hide" then
        mainFrame:Hide()
    elseif msg == "show" then
        mainFrame:Show()
    else
        if mainFrame:IsShown() then
            mainFrame:Hide()
        else
            mainFrame:Show()
        end
    end
end

-- Event frame
local eventFrame = CreateFrame("Frame", "PlayerSetupEventFrame")
eventFrame:SetScript("OnEvent", function(self, event, ...)
    if event == "ADDON_LOADED" then
        local addonName = ...
        if addonName == "PlayerSetup" then
            DEFAULT_CHAT_FRAME:AddMessage("Player Setup addon loaded! Use /playersetup or /psetup to toggle window", 0, 1, 0)
            mainFrame:Show()
        end
    end
end)

eventFrame:RegisterEvent("ADDON_LOADED") 